module st_clk(
  clk,
  reset_n,
  st_clk 
);

  input clk;
  input reset_n;
  output st_clk;
  
  // Clock divider for signaltap.
  // The 1c20 board's 50MHz clock drives pin K5. The IR signal from the
  // remote control lives at in a much lower spectrum, with periods in
  // the 100s of microseconds.  I want to sample the IR signal at a frequency
  // fast enough to catch each transition with reasonable precision, but not
  // at such a high frequency that I waste sample memory.  I'll use a binary
  // counter of ST_CLK_WIDTH bits as a clock divider.

  `define ST_CLK_WIDTH 8
  // input clk: 50MHz
  // st_clk frequency: 50MHz / (2 ** ST_CLK_WIDTH)
  // at ST_CLK_WIDTH=7, st_clk frequency is: 390625Hz.
  reg [(`ST_CLK_WIDTH - 1) : 0] divider /* synthesis noprune */;
  wire [(`ST_CLK_WIDTH - 1) : 0] p1_divider = divider + 1'b1;
  
  wire divider_clken = 1'b1;
  always @(posedge clk or negedge reset_n) begin
    if (!reset_n) begin
      divider <= `ST_CLK_WIDTH'b0;
    end
    else if (divider_clken) begin
      divider <= p1_divider;
    end
  end
  
  // Select the sampling clock from the counter msb.
  assign st_clk = divider[`ST_CLK_WIDTH - 1];
  
endmodule
