module st_module(
  clk,
  reset_n,
  data_in,
);
  input clk;
  input reset_n;
  input data_in;

  st_clk the_st_clk (
    .clk (clk),
    .reset_n (reset_n),
    .st_clk (st_clk)  
  );

  // I also want a counter to count st_clk periods. 
  `define COUNTER_WIDTH 12
  reg [(`COUNTER_WIDTH - 1) : 0] counter;
  `define DELTA_WIDTH 10
  wire [(`DELTA_WIDTH - 1) : 0] delta;
  reg d1_data_in;

  always @(posedge st_clk or negedge reset_n) begin
    if (!reset_n) begin
      d1_data_in <= 1'b1;
    end
    else begin
      d1_data_in <= data_in;
    end
  end

  assign delta = 
    (d1_data_in ^ data_in && (counter <= `COUNTER_WIDTH'd900)) ? 
      (counter[(`DELTA_WIDTH - 1) : 0] + 1) : 
      `DELTA_WIDTH'b0;

  always @(posedge st_clk or negedge reset_n) begin
    if (!reset_n) begin
      counter <= `COUNTER_WIDTH'b0;
    end
    else if (d1_data_in != data_in) begin
      counter <= 0;
    end
    else begin
      counter <= counter + 1'b1;
    end
  end

  st my_little_st(
    .acq_clk (st_clk),
    .acq_data_in ({delta, data_in}),
    .acq_trigger_in (data_in)
  );
endmodule
